pub struct AuthenticationClient;Expand description
Helper structure for obtaining token using authorization through credentials in Selenium - browser automation software
Implementations
Sourceimpl AuthenticationClient
impl AuthenticationClient
Enters application and user data through Selenium to get temporary code
Sourcepub async fn perform_authentication(
&self,
application: &ApplicationCredentials<'_>,
authorization_code: &str,
) -> Result<UserOpenAuthorizationResponse>
pub async fn perform_authentication( &self, application: &ApplicationCredentials<'_>, authorization_code: &str, ) -> Result<UserOpenAuthorizationResponse>
Continues the authorization process, receives access token from the temporary code
Sourcepub async fn refresh_token(
&self,
refresh_token: &str,
) -> Result<UserOpenAuthorizationResponse>
pub async fn refresh_token( &self, refresh_token: &str, ) -> Result<UserOpenAuthorizationResponse>
Creates an access token renewal request